@@ -1,9 +1,13 @@
+from __future__ import absolute_import
+
 from django.conf import settings
 from django.core import exceptions
 from django.utils import importlib
 
 from datastream import Datastream
 
+from . import signals
+
 datastream = None
 
 # Load the backend as specified in configuration
@@ -25,4 +29,7 @@ if getattr(settings, 'DATASTREAM_BACKEND', None) is not None:
 
         backend = cls(**getattr(settings, 'DATASTREAM_BACKEND_SETTINGS', {}))
 
-    datastream = Datastream(backend)
+    def callback(stream_id, granularity, datapoint):
+        signals.new_datapoint.send(sender=datastream, stream_id=stream_id, granularity=granularity, datapoint=datapoint)
+
+    datastream = Datastream(backend, callback)
